from setuptools import setup

import tju

setup(
    name="tju",
    version=tju.__version__,
    author="super",
    author_email="hi@repus.me",
    description="The Python TJU client for humans.",
    url="https://github.com/superpung/tju",
    packages=['tju']
)
